
*****************************************************************************
******************************REPLICATION CODE*******************************
*****WHO LIES ABOUT ELECTORAL GIFTS? - CHAD P. KIEWIET DE JONGE - POQ********
*****************************************************************************

clear

***NOTE: Install user created package splitvallabels

***SET CURRENT DIRECTORY TO FOLDER WITH DATASETS

cd "C:\Users\Politcide08\Dropbox\Vote Buying\Social Desirability Bias\POQ submission\Forthcoming\Replication\Replication_v2"
use "Complete sdb dataset_2014.dta"


*****************************************************************************
***Descriptive Statistics - Appendix B
*****************************************************************************

svyset [pw=wt]
label define study_num 9 "Argentina 2011" 6 "Bolivia 2009" 7 "Bolivia 2010" 5 "Chile 2009" 8 "Guatemala 2011" 3 "Honduras 2009" 2 "Mexico 2009" 1 "Nicaragua 2008" 10 "Nicaragua 2011" 4 "Uruguay 2009" , replace
label values study_num study_num

set seed 9875

foreach var of varlist list treat indVB edu know std_inc incNA incREF incDK std_count PIDstrength clientexp  Voted female c_age  monitor recip stigma4 {
	tabstat `var'  [aw=wt] , by(study_num) statistics(n min max mean sd) columns(statistics) nototal format(%9.2f)
}

tabstat stigma4 [aw=wt] if testpoor==0, by(study_num) statistics(n min max mean sd) columns(statistics) nototal 
tabstat stigma4 [aw=wt] if testpoor==1, by(study_num) statistics(n min max mean sd) columns(statistics) nototal 

*****************************************************************************
***Aggregate Vote buying estimates, original data
*****************************************************************************

** Simulate Estimates of Vote Buying According to Direct Question

forvalues i= 1/10 {
	clear matrix
	tab study_num if study_num==`i'
	svy: logit indVB if study_num==`i'
	matrix m=e(b)
	matrix V=e(V)
	preserve
	drawnorm lg_est_ind, n(10000) means(m) cov(V) clear 
	gen est_ind=invlogit(lg_est_ind)
	gen study_num=`i'
	recode study_num (4 5 6 7=.) (8=4) (9=5) (10=6), gen(study_num2)
	gen id=_n
	sort study_num id
	save ind_`i'.dta, replace
	restore
	}


	
** Simulate Estimates of Vote Buying According to List Experiment

clear matrix
forvalues i= 1/10 {
	tab study_num if study_num==`i'
	svy: reg list treat if study_num==`i'
	preserve
	drawnorm est_VBlist est_VBlistcons, n(10000) means(e(b)) cov(e(V)) clear 
	gen study_num=`i'
	recode study_num (4 5 6 7=.) (8=4) (9=5) (10=6), gen(study_num2)
	gen id=_n
	sort study_num id
	save est_VBlist_`i'.dta, replace
	restore
	}
	
**********************

*****************************************************************************
***Individual Level Models and Model Simulations
*****************************************************************************


****Individual models by study

*****************************************************************************
**Nicaragua 2008
*****************************************************************************


firthlogit indVB c_female c_age c_edu std_inc c_incNA std_count c_monitor c_PIDstrength  c_clientexp if study_num==1  // Firth logit used to to perfect prediction of incNA=0
estimates store m1a

svy: reg list c.treat#(c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_clientexp) treat c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_clientexp if study_num==1, vsquish
estimates store m1b

preserve
estimates restore m1a

drawnorm d_female d_age d_edu d_std_inc d_incNA d_std_count d_monitor d_PIDstrength  d_clientexp d_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=1
gen id=_n
sort study_num id
save d_1.dta, replace
restore

preserve
estimates restore m1b

drawnorm t_female t_age t_edu t_std_inc t_incNA t_std_count t_monitor t_PIDstrength t_clientexp t_cons x_female x_age x_edu x_std_inc x_incNA x_std_count x_monitor x_PIDstrength  x_clientexp x_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=1
gen id=_n
sort study_num id
save l_1.dta, replace
restore


*****************************************************************************
**Mexico 2009
*****************************************************************************

svy: logit indVB c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_Voted c.c_clientexp if study_num==2
estimates store m2a

svy: reg list c.treat#(c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_Voted c.c_clientexp) treat c.c_female c.c_age c.c_edu c.std_inc c.c_incNA  c.std_count c.c_monitor c.c_PIDstrength c.c_Voted c.c_clientexp if study_num==2, vsquish
estimates store m2b

preserve
estimates restore m2a

drawnorm d_female d_age d_edu d_std_inc d_incNA d_std_count d_monitor d_PIDstrength d_Voted d_clientexp d_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=2
gen id=_n
sort study_num id
save d_2.dta, replace
restore

preserve
estimates restore m2b

drawnorm t_female t_age t_edu t_std_inc t_incNA t_std_count t_monitor t_PIDstrength t_Voted t_clientexp t_cons x_female x_age x_edu x_std_inc x_incNA x_std_count x_monitor x_PIDstrength x_Voted x_clientexp x_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=2
gen id=_n
sort study_num id
save l_2.dta, replace
restore

*****************************************************************************
**Honduras 2009
*****************************************************************************

svy: logit indVB c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp if study_num==3
estimates store m3a

svy: reg list c.treat#(c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp) treat c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count  c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp if study_num==3, vsquish
estimates store m3b

preserve
estimates restore m3a

drawnorm d_female d_age d_edu d_std_inc d_incNA d_std_count  d_monitor d_PIDstrength d_recip d_Voted d_clientexp d_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=3
gen id=_n
sort study_num id
save d_3.dta, replace
restore

preserve
estimates restore m3b

drawnorm t_female t_age t_edu t_std_inc t_incNA t_std_count t_monitor t_PIDstrength t_recip t_Voted t_clientexp t_cons x_female x_age x_edu x_std_inc x_incNA x_std_count x_monitor x_PIDstrength x_recip x_Voted x_clientexp x_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=3
gen id=_n
sort study_num id
save l_3.dta, replace
restore


*****************************************************************************
**Guatemala 2011
*****************************************************************************

tab study if study_num==8

svy: logit indVB c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp if study_num==8
estimates store m8a

svy: reg list c.treat#(c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp) treat c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp if study_num==8, vsquish
estimates store m8b

preserve
estimates restore m8a

drawnorm d_female d_age d_edu d_std_inc d_incNA d_std_count d_monitor d_PIDstrength d_recip d_Voted d_clientexp d_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=8
gen id=_n
sort study_num id
save d_4.dta, replace
restore

preserve
estimates restore m8b

drawnorm t_female t_age t_edu t_std_inc t_incNA t_std_count t_monitor t_PIDstrength t_recip t_Voted t_clientexp t_cons x_female x_age x_edu x_std_inc x_incNA x_std_count x_monitor x_PIDstrength x_recip x_Voted x_clientexp x_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=8
gen id=_n
sort study_num id
save l_4.dta, replace
restore

*****************************************************************************
**Argentina 2011
*****************************************************************************

tab study if study_num==9

svy: logit indVB c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp if study_num==9
estimates store m9a

svy: reg list c.treat#(c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp) treat c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp if study_num==9, vsquish
estimates store m9b

preserve
estimates restore m9a

drawnorm d_female d_age d_edu d_std_inc d_incNA d_std_count d_monitor d_PIDstrength d_recip d_Voted d_clientexp d_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=9
gen id=_n
sort study_num id
save d_5.dta, replace
restore

preserve
estimates restore m9b

drawnorm t_female t_age t_edu t_std_inc t_incNA t_std_count t_monitor t_PIDstrength t_recip t_Voted t_clientexp t_cons x_female x_age x_edu x_std_inc x_incNA x_std_count x_monitor x_PIDstrength x_recip x_Voted x_clientexp x_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=9
gen id=_n
sort study_num id
save l_5.dta, replace
restore

*****************************************************************************
**Nicaragua 2011
*****************************************************************************

tab study if study_num==10

svy: logit indVB c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp if study_num==10
estimates store m10a

svy: reg list c.treat#(c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp) treat c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count  c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp if study_num==10, vsquish
estimates store m10b

preserve
estimates restore m10a

drawnorm d_female d_age d_edu d_std_inc d_incNA d_std_count  d_monitor d_PIDstrength d_recip d_Voted d_clientexp d_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=10
gen id=_n
sort study_num id
save d_6.dta, replace
restore

preserve
estimates restore m10b

drawnorm t_female t_age t_edu t_std_inc t_incNA t_std_count  t_monitor t_PIDstrength t_recip t_Voted t_clientexp t_cons x_female x_age x_edu x_std_inc x_incNA x_std_count  x_monitor x_PIDstrength x_recip x_Voted x_clientexp x_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=10
gen id=_n
sort study_num id
save l_6.dta, replace
restore

*****************************************************************************
***Alternative Statistical tables, Appendix C
*****************************************************************************

*****************************************************************************
*Add political awareness , Mexico
*****************************************************************************

svy: logit indVB c.c_female c.c_age c.c_edu c.c_know c.std_inc c.c_incREF c.c_incDK c.std_count c.c_monitor c.c_PIDstrength c.c_Voted c.c_clientexp if study_num==2
estimates store m2c

svy: reg list c.treat#(c.c_female c.c_age c.c_edu c.c_know c.std_inc c.c_incREF c.c_incDK c.std_count c.c_monitor c.c_PIDstrength c.c_Voted c.c_clientexp) treat c.c_female c.c_age c.c_edu c.c_know c.std_inc c.c_incREF c.c_incDK c.std_count c.c_monitor c.c_PIDstrength c.c_Voted c.c_clientexp if study_num==2, vsquish
estimates store m2d

preserve
estimates restore m2c

drawnorm d_female d_age d_edu d_know d_std_inc d_incNA d_incDK d_std_count d_monitor d_PIDstrength d_Voted d_clientexp d_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=22
gen id=_n
sort study_num id
save d_2b.dta, replace
restore

preserve
estimates restore m2d

drawnorm t_female t_age t_edu t_know t_std_inc t_incNA t_incDK t_std_count t_monitor t_PIDstrength t_Voted t_clientexp t_cons x_female x_age x_edu x_know x_std_inc x_incNA x_incDK x_std_count x_monitor x_PIDstrength x_Voted x_clientexp x_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=22
gen id=_n
sort study_num id
save l_2b.dta, replace
restore

*****************************************************************************
*test by stigma experiment Honduras
*****************************************************************************

firthlogit indVB c_female c_age c_edu std_inc c_incNA std_count c_monitor c_PIDstrength c_recip c_Voted c_clientexp stigma4 if study_num==3 & testpoor==0 
estimates store m3c

svy: logit indVB c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp i.stigma4 if study_num==3 & testpoor==1
estimates store m3d

svy: reg list c.treat#(c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp c.stigma4) treat c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count  c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp c.stigma4 if study_num==3 & testpoor==0, vsquish
estimates store m3e

svy: reg list c.treat#(c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp i.stigma4) treat c.c_female c.c_age c.c_edu c.std_inc c.c_incNA c.std_count  c.c_monitor c.c_PIDstrength c.c_recip c.c_Voted c.c_clientexp i.stigma4 if study_num==3 & testpoor==1, vsquish
estimates store m3f

preserve
estimates restore m3c

drawnorm d_female d_age d_edu d_std_inc d_incNA d_std_count  d_monitor d_PIDstrength d_recip d_Voted d_clientexp d_stigma d_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=33
gen id=_n
sort study_num id
save d_3a.dta, replace
restore

preserve
estimates restore m3d

drawnorm d_female d_age d_edu d_std_inc d_incNA d_std_count  d_monitor d_PIDstrength d_recip d_Voted d_clientexp d_stigma1 d_stigma2 d_stigma3 d_stigma4 d_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=34
gen id=_n
sort study_num id
save d_3b.dta, replace
restore

preserve
estimates restore m3e

drawnorm t_female t_age t_edu t_std_inc t_incNA t_std_count t_monitor t_PIDstrength t_recip t_Voted t_clientexp t_stigma t_cons x_female x_age x_edu x_std_inc x_incNA x_std_count x_monitor x_PIDstrength x_recip x_Voted x_clientexp x_stigma x_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=33
gen id=_n
sort study_num id
save l_3c.dta, replace
restore

preserve
estimates restore m3f

drawnorm t_female t_age t_edu t_std_inc t_incNA t_std_count t_monitor t_PIDstrength t_recip t_Voted t_clientexp t_stigma1 t_stigma2 t_stigma3 t_stigma4 t_cons x_female x_age x_edu x_std_inc x_incNA x_std_count x_monitor x_PIDstrength x_recip x_Voted x_clientexp x_stigma1 x_stigma2 x_stigma3 x_stigma4 x_cons, n(10000) means(e(b)) cov(e(V)) clear 
gen study_num=34
gen id=_n
sort study_num id
save l_3d.dta, replace
restore

*****************************************************************************
***Export Statistical Tables
*****************************************************************************


*Table C1
estout *a using indVB.txt,  cells(b(star fmt(2))  se(par(`"="("' `")""'))) starlevels(+ 0.10 * 0.05 ** 0.01) stats(N, fmt(%9.0g)) /// 
							mlabels("Nicaragua '08" "Mexico '09" "Honduras '09" "Guatemala '11" "Argentina '11" "Nicaragua '11") ///
							varlabels(c_female	"Gender"	c_age	"Age"	c_edu	"Education"	std_inc	"Income/SES"	c_monitor	"Ballot Secrecy"	c_PIDstrength	"PID Strength"	c_clientexp	"Clientelism Exposure"	c_incNA	"Income NA" std_count "Missing Count"	c_Voted	"Prior Voter"	c_recip "Reciprocity" _cons "Constant") ///
							order(c_female c_age c_edu std_inc c_incNA  c_PIDstrength c_clientexp c_monitor c_recip c_Voted ) ///
							style(tab) collabels(none) legend  replace
*Table C2							
estout *b using listVB.txt,  cells(b(star fmt(2)) se(par(`"="("' `")""'))) starlevels(+ 0.10 * 0.05 ** 0.01) stats(N, fmt(%9.0g)) /// 
							mlabels("Nicaragua '08" "Mexico '09" "Honduras '09"  "Guatemala '11" "Argentina '11" "Nicaragua '11") ///
							varlabels(c.treat#c.c_female "Gender" c.treat#c.c_age "Age" c.treat#c.c_edu "Education" c.treat#c.std_inc "Income/SES" c.treat#c.c_incNA "Income NA" c.treat#c.std_count "Missing Count" c.treat#c.c_monitor "Ballot Secrecy" c.treat#c.c_PIDstrength "PID Strength" c.treat#c.c_recip "Reciprocity" c.treat#c.c_Voted "Prior Voter" c.treat#c.c_clientexp "Clientelism Exposure" treat "Treat Constant" c_female	"Gender"	c_age	"Age"	c_edu	"Education"	std_inc	"Income/SES"	c_PIDstrength	"PID Strength"	c_clientexp	"Clientelism Exposure"	c_incNA	"Income NA" std_count "Missing Count"	c_Voted	"Prior Voter" c_monitor	"Ballot Secrecy"	c_recip "Reciprocity" _cons "Control Constant") ///
							order("Treatment List" c.treat#c.c_female c.treat#c.c_age c.treat#c.c_edu c.treat#c.std_inc c.treat#c.c_incNA c.treat#c.std_count  c.treat#c.c_PIDstrength c.treat#c.c_clientexp c.treat#c.c_monitor c.treat#c.c_recip c.treat#c.c_Voted  treat " " "Control List" c_female c_age c_edu std_inc c_incNA std_count  c_PIDstrength c_clientexp c_monitor c_recip c_Voted " " ) ///
							style(tab) collabels(none) legend  replace


*Table C3							
estout m2c m3c m3d using indRobustness.txt,  cells("b(star fmt(2))   se(par([ ]))" )  starlevels(+ 0.10 * 0.05 ** 0.01) stats(N, fmt(%9.0g)) /// 
							mlabels("Mexico '09 Alt" "Honduras '09 Poor Client" "Honduras '09 Middle Class Client") ///
							varlabels(c_female	"Gender"	c_age	"Age"	c_edu	"Education" c_know "Awareness"	std_inc	"Income/SES"	c_monitor	"Ballot Secrecy"	c_PIDstrength	"PID Strength"	c_clientexp	"Clientelism Exposure"	c_incREF	"Income Refusal" c_incDK "Income Don't Know" c_incNA "Income No Answer" std_count "Missing Count"	c_Voted	"Prior Voter"	c_recip "Reciprocity" _cons "Constant" stigma4 "Unacceptable 4 point" 1b.stigma4 "Acceptable" 2.stigma4 "Understandable/Unacceptable" 3.stigma4 "Unacceptable" 4.stigma4 "Totally Unacceptable") ///
							order(c_female c_age c_edu c_know std_inc c_incREF c_incDK c_incNA std_count  c_PIDstrength c_clientexp c_monitor c_recip c_Voted "  " stigma4 2.stigma4 3.stigma4 4.stigma4 _cons ) ///
							style(tab) collabels(none) legend  replace drop(1b.stigma4)

*Table C4
estout m2d m3e m3f using listRobustness.txt,  cells("b(star fmt(2))   se(par([ ]))") starlevels(+ 0.10 * 0.05 ** 0.01) stats(N, fmt(%9.0g)) /// 
							mlabels("Nicaragua '08" "Mexico '09" "Honduras '09"  "Guatemala '11" "Argentina '11" "Nicaragua '11") ///
							varlabels(c.treat#c.c_female "Gender" c.treat#c.c_age "Age" c.treat#c.c_edu "Education" c.treat#c.c_know "Awareness" c.treat#c.std_inc "Income/SES" c.treat#c.c_incNA "Income NA" c.treat#c.c_incREF "Income Refused" c.treat#c.c_incDK "Income Don't Know" c.treat#c.std_count "Missing Count" c.treat#c.c_monitor "Ballot Secrecy" c.treat#c.c_PIDstrength "PID Strength" c.treat#c.c_recip "Reciprocity" c.treat#c.c_Voted "Prior Voter" c.treat#c.c_clientexp "Clientelism Exposure" treat "Treat Constant" c.treat#c.stigma4 "Unacceptable 4 point"  2.stigma4#c.treat "Understandable/Unacceptable" 3.stigma4#c.treat "Unacceptable" 4.stigma4#c.treat "Totally Unacceptable" c_female	"Gender"	c_age	"Age"	c_edu	"Education" c_know "Awareness"	std_inc	"Income/SES"	c_PIDstrength	"PID Strength"	c_clientexp	"Clientelism Exposure"	c_incNA	"Income NA" c_incREF	"Income Refuse" c_incDK	"Income Don't Know" std_count "Missing Count"	c_Voted	"Prior Voter" c_monitor	"Ballot Secrecy"	c_recip "Reciprocity" _cons "Control Constant" stigma4 "Unacceptable 4 point" 1b.stigma4 "Acceptable" 2.stigma4 "Understandable/Unacceptable" 3.stigma4 "Unacceptable" 4.stigma4 "Totally Unacceptable") ///
							order("Treatment List" c.treat#c.c_female c.treat#c.c_age c.treat#c.c_edu c.treat#c.c_know c.treat#c.std_inc c.treat#c.c_incREF c.treat#c.c_incDK c.treat#c.c_incNA c.treat#c.std_count  c.treat#c.c_PIDstrength c.treat#c.c_clientexp c.treat#c.c_monitor c.treat#c.c_recip c.treat#c.c_Voted c.treat#c.stigma4 2.stigma4#c.treat 3.stigma4#c.treat 4.stigma4#c.treat treat " " "Control List" c_female c_age c_edu c_know std_inc c_incREF c_incDK c_incNA std_count  c_PIDstrength c_clientexp c_monitor c_recip c_Voted stigma4 2.stigma4 3.stigma4 4.stigma4 " " ) ///
							style(tab) collabels(none) legend  replace drop(1b.stigma4 1b.stigma4#co.treat)


*****************************************************************************
*****************************************************************************
*****************************************************************************



*****************************************************************************
***Move to simulated dataset for inference about SDB
*****************************************************************************

clear


***Merge together simulated datasets

use ind_1.dta

forvalues i=2/10 {
	append using ind_`i'.dta
	}
	
sort study_num id	


forvalues i=1/10{
	merge study_num id using est_VBlist_`i'.dta, update
	tab _merge
	drop _merge
	sort study_num id
	}

forvalues i=1/6{
	merge study_num id using d_`i'.dta, update
	tab _merge
	drop _merge
	sort study_num id
	}

forvalues i=1/6{
	merge study_num id using l_`i'.dta, update
	tab _merge
	drop _merge
	sort study_num id
	}

*Merge in alternative models
append  using d_2b.dta
sort study_num id
merge study_num	id using l_2b.dta, update
drop _merge
sort study_num id

append using d_3a.dta
sort study_num id
merge 1:1 study_num id using l_3c.dta , update
drop _merge
sort study_num id
append using d_3b.dta
sort study_num id
merge study_num id using l_3d.dta, update
drop _merge
sort study_num id

recode study_num (22=2) (33 34=3), gen(study_num3) 
sort study_num3

*merge in variable descriptive statistics for predictions
merge m:1 study_num3 using variable_values.dta
drop _merge
merge m:1 study_num using Aggregate.dta
drop _merge


*Label studies
label define study_num 9 "Argentina 2011" 6 "Bolivia 2009" 7 "Bolivia 2010" 5 "Chile 2009" 8 "Guatemala 2011" 3 "Honduras 2009" 2 "Mexico 2009" 1 "Nicaragua 2008" 10 "Nicaragua 2011" 4 "Uruguay 2009" 22 "Mexico Alternative" 33 "Honduras - Nonpoor Stigma" 34 "Honduras - Poor Stigma", replace
label values study_num study_num

label define study_num2 5 "Argentina 2011"  4 "Guatemala 2011" 3 "Honduras 2009" 2 "Mexico 2009" 1 "Nicaragua 2008" 6 "Nicaragua 2011"   7 "Meta Estimate", replace
label values study_num2 study_num2


sort study_num id
moreobs 1
replace study_num2=7 in 130001

*****************************************************************************
***Move to simulated dataset for inference about SDB
*****************************************************************************


*********Inference

*****************************************************************************
***Create Variables for Figure 1
*****************************************************************************

*******Avg social desirability bias, full sample
egen m_est_VBlist=mean(est_VBlist), by(study_num)
egen mu_est_VBlist=mean(m_est_VBlist) 
egen m_est_ind=mean(est_ind), by(study_num)
egen mu_est_ind=mean(m_est_ind) 
egen l_est_VBlist=pctile(est_VBlist), p(2.5) by(study_num)
egen h_est_VBlist=pctile(est_VBlist), p(97.5) by(study_num)
egen l_est_ind=pctile(est_ind), p(2.5) by(study_num)
egen h_est_ind=pctile(est_ind), p(97.5) by(study_num)

*adjustments to fix list est.< direct est.
gen adj_est_VBlist=est_VBlist
replace adj_est_VBlist=est_ind if est_ind>est_VBlist
gen m_adj_est_VBlist=m_est_VBlist
replace m_adj_est_VBlist=m_est_ind if m_est_VBlist<m_est_ind
egen mu_adj_est_VBlist=mean(m_adj_est_VBlist) if study_num2<7
gen c_adj_est_VBlist=m_adj_est_VBlist-mu_adj_est_VBlist

*absolute social desirability bias, raw and adjusted
gen sdb=est_VBlist-est_ind
egen m_sdb=mean(sdb), by(study_num)
egen l_sdb=pctile(sdb), p(2.5) by(study_num)
egen h_sdb=pctile(sdb), p(97.5) by(study_num)

gen adj_sdb=adj_est_VBlist-est_ind
gen m_adj_sdb=m_adj_est_VBlist-m_est_ind
egen sd_adj_sdb=sd(sdb), by(study_num)
gen l_adj_sdb=m_adj_sdb-1.96*sd_adj_sdb
gen h_adj_sdb=m_adj_sdb+1.96*sd_adj_sdb

egen mu_adj_sdb=mean(m_adj_sdb) 
gen c_adj_sdb=m_adj_sdb-mu_adj_sdb

**precision weighted average

metan m_adj_sdb sd_adj_sdb if id==1, random nograph
metan m_adj_sdb sd_adj_sdb if id==1 & m_adj_sdb>0, random nograph

gen xaxis2=study_num*2 if study_num<11
gen xaxis1=xaxis2-.25
gen xaxis3=xaxis2+.25
gen xaxis4=xaxis2+.5


label define xaxis2 18 "Argentina '11" 12 "Bolivia '09" 14 "Bolivia '10" 10 "Chile '09" 16 "Guatemala '11" 6 "Honduras '09" 2 "Nicaragua '08" 4 "Mexico '09" 20 "Nicaragua '11" 8 "Uruguay '09" , replace
label values xaxis2 xaxis2

gen xaxis2b=study_num2*2 if study_num2<8
gen xaxis1b=xaxis2b-.25
gen xaxis3b=xaxis2b+.25
gen xaxis4b=xaxis2b+.5

replace xaxis3b=14 if study_num2==7

label define xaxis2b 10 "Argentina '11"  8 "Guatemala '11" 6 "Honduras '09" 2 "Nicaragua '08" 4 "Mexico '09" 12 "Nicaragua '11" 14 "Random-Effects Meta-Average", replace
label values xaxis2b xaxis2b


******************************************************************************
***Figure 1
*****************************************************************************

tabstat m_est_VBlist l_est_VBlist h_est_VBlist m_est_ind l_est_ind h_est_ind m_adj_sdb l_adj_sdb h_adj_sdb if id==1 & study_num<11, by(study_num) 
tabstat m_est_VBlist l_est_VBlist h_est_VBlist m_est_ind l_est_ind h_est_ind m_adj_sdb l_adj_sdb h_adj_sdb if id==1 & study_num2!=., by(study_num) 
 

graph set window fontface "Times New Roman"

twoway (scatter m_est_ind xaxis2, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_est_ind xaxis2 l_est_ind xaxis2, lcolor(black) lwidth(vthin)) /// 
		(scatter m_est_VBlist xaxis1, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_est_VBlist xaxis1 h_est_VBlist xaxis1, lcolor(black) lwidth(vthin)) ///
		(scatter m_adj_sdb xaxis3, lcolor(black) mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_adj_sdb xaxis3 h_adj_sdb xaxis3, lcolor(black) lwidth(vthin)) if id==1 & study_num<11, ///
		ytitle(Estimated Proportion) ytitle(, size( msmall)) ylabel(, labels ) ///
		xtitle(" " " " " " " " " " "Study") xtitle(, size( medsmall) color(none)) xlabel(2(2)20, labels labsize( medsmall) angle(45) ///
		format(%12s) valuelabels) legend(on order(3 "LE Estimate" 1 "Direct Estimate" 5 "SDB Estimate")  ///
		rows(1) size( medsmall) position(12) ring(0)) graphregion(color(white)) 
		
graph export Figure1.tif, replace


******************************************************************************
***Table 1 + Aggregate Descriptives + Aggregate Robustness
*****************************************************************************

* liars
gen liars=1-est_ind/adj_est_VBlist
gen m_liars=1-m_est_ind/m_adj_est_VBlist
egen sd_liars=sd(liars), by(study_num)
gen l_liars=m_liars-1.96*sd_liars
gen h_liars=m_liars+1.96*sd_liars

egen m_clear_VB2=mean(clear_VB2) if study_num2<7
gen c_clear_VB2=clear_VB2-m_clear_VB2

*Table 1 - Testing H3 with bivariate correlations
tabstat m_liars  clear_VB clear_VB2 elec_type comp clientelism ln_GDP_cap Gini if id==1 & study_num<11, by(study_num)
pwcorr m_liars  clear_VB clear_VB2 elec_type comp clientelism ln_GDP_cap Gini if id==1, sig

*Aggregate descriptive statistics, Table B2, supplementary materials
tabstat m_liars  clear_VB clear_VB2 elec_type comp clientelism ln_GDP_cap Gini if id==1 & study_num<11,  statistics(n min max mean sd) columns(statistics)  format(%9.2f)


* check robustness using glm (since liars=proportion), one and two tailed tests
foreach var of varlist clear_VB clear_VB2 elec_type comp clientelism ln_GDP_cap Gini {
	glm m_liars `var' if id==1, family(binomial) link(logit)
	di "One tailed p-value= "(1-normal( abs(_b[`var']/_se[`var'])))
}


******************************************************************************
**********Individual level analysis
******************************************************************************

******************************************************************************
** H1: Political Awareness / Education
******************************************************************************

sort study_num2 id

*Postsecondary education VB estimates
gen Hedu_ind=invlogit(d_edu*c_max_edu+d_cons) 
egen m_Hedu_ind=mean(Hedu_ind) , by(study_num)
gen Hedu_list=t_edu*c_max_edu+t_cons 
egen m_Hedu_list=mean(Hedu_list) , by(study_num)

*Primary or less education VB estimates
gen Ledu_ind=invlogit(d_edu*c_min_edu+d_cons) 
egen m_Ledu_ind=mean(Ledu_ind) , by(study_num)
gen Ledu_list=t_edu*c_min_edu+t_cons 
egen m_Ledu_list=mean(Ledu_list) , by(study_num)

*Postsecondary education SDB estimates
gen Hedu_sdb=Hedu_list-Hedu_ind 
egen sd_Hedu_sdb=sd(Hedu_sdb) , by(study_num)
gen m_Hedu_sdb=m_Hedu_list-m_Hedu_ind 
replace m_Hedu_sdb=0 if m_Hedu_sdb<0 
gen z_Hedu_sdb=m_Hedu_sdb/sd_Hedu  
gen w_Hedu_sdb=1/sd_Hedu_sdb^2  
gen l_Hedu_sdb=m_Hedu_sdb-1.96*sd_Hedu_sdb  
gen h_Hedu_sdb=m_Hedu_sdb+1.96*sd_Hedu_sdb  

*Primary or less education SDB estimates
gen Ledu_sdb=Ledu_list-Ledu_ind  
egen sd_Ledu_sdb=sd(Ledu_sdb)  , by(study_num)
gen m_Ledu_sdb=m_Ledu_list-m_Ledu_ind  
replace m_Ledu_sdb=0 if m_Ledu_sdb<0  
gen z_Ledu_sdb=m_Ledu_sdb/sd_Ledu  
gen w_Ledu_sdb=1/sd_Ledu_sdb^2  
gen l_Ledu_sdb=m_Ledu_sdb-1.96*sd_Ledu_sdb  
gen h_Ledu_sdb=m_Ledu_sdb+1.96*sd_Ledu_sdb  

*Difference in SDB by education
gen edu_sdb=Hedu_sdb-Ledu_sdb  
egen sd_edu_sdb=sd(edu_sdb) ,  by(study_num)
gen m_edu_sdb=m_Hedu_sdb-m_Ledu_sdb 
gen z_edu_sdb=m_edu_sdb/sd_Hedu 
gen w_edu_sdb=1/sd_edu_sdb^2 
gen l_edu_sdb=m_edu_sdb-1.96*sd_edu_sdb 
gen h_edu_sdb=m_edu_sdb+1.96*sd_edu_sdb 


*Meta analysis of effect size
metan m_edu_sdb sd_edu_sdb if id==1 & study_num2<7,  random nograph 

replace m_edu_sdb=r(ES) if study_num2==7
replace sd_edu_sdb=r(seES) if study_num2==7
replace l_edu_sdb=r(ci_low) if study_num2==7
replace h_edu_sdb=r(ci_upp) if study_num2==7

gen p_edu_sdb=1-normal(m_edu_sdb/sd_edu_sdb)
format p_edu_sdb %9.2f
table study_num2, c(mean p_edu_sdb)

*Figure 2

splitvallabels xaxis2b , length(14)
twoway 	(scatter m_Ledu_sdb xaxis2b, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_Ledu_sdb xaxis2b h_Ledu_sdb xaxis2b, lcolor(black) lwidth(vthin)) ///
		(scatter m_Hedu_sdb xaxis1b, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_Hedu_sdb xaxis1b l_Hedu_sdb xaxis1b, lcolor(black) lwidth(vthin)) /// 
		(scatter m_edu_sdb xaxis3b, mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_edu_sdb xaxis3b h_edu_sdb xaxis3b, lcolor(black) lwidth(vthin)) if id>9999 & study_num2!=., ///
		ytitle(Estimated Social Desirability Bias) ytitle(, size(medsmall)) ylabel(, labels ) ///
		xtitle( "Study") xtitle(, size(medsmall) color(none)) xlabel(#7 `r(relabel)', labels labsize(small)    ///
		format(%12s) valuelabel) legend(on order(3 "Postsecondary" 1 "Primary or Less"  5 "Difference") ///
		rows(1) size(medsmall) position(12) ring(0)) xscale(range(1.5 14.5)) graphregion(color(white))

graph export Figure2.tif, replace


******************************************************************************
*Robustness of H1: Add political awareness to Mexico model
******************************************************************************

* High awareness VB estimates
gen Hknow_ind=invlogit(d_know*(sd_know)+d_cons)
egen m_Hknow_ind=mean(Hknow_ind), by(study_num)
gen Hknow_list=t_know*sd_know+t_cons
egen m_Hknow_list=mean(Hknow_list), by(study_num)

* low awareness VB estimates
gen Lknow_ind=invlogit(d_know*(-sd_know)+d_cons)
egen m_Lknow_ind=mean(Lknow_ind), by(study_num)
gen Lknow_list=t_know*(-sd_know)+t_cons
egen m_Lknow_list=mean(Lknow_list), by(study_num)

* High awareness SDB estimates
gen Hknow_sdb=Hknow_list-Hknow_ind
egen sd_Hknow_sdb=sd(Hknow_sdb), by(study_num)
gen m_Hknow_sdb=m_Hknow_list-m_Hknow_ind
replace m_Hknow_sdb=0 if m_Hknow_sdb<0
gen l_Hknow_sdb=m_Hknow_sdb-1.96*sd_Hknow_sdb
gen h_Hknow_sdb=m_Hknow_sdb+1.96*sd_Hknow_sdb

* Low awareness SDB estimates
gen Lknow_sdb=Lknow_list-Lknow_ind
egen sd_Lknow_sdb=sd(Lknow_sdb), by(study_num)
gen m_Lknow_sdb=m_Lknow_list-m_Lknow_ind
replace m_Lknow_sdb=0 if m_Lknow_sdb<0
gen l_Lknow_sdb=m_Lknow_sdb-1.96*sd_Lknow_sdb
gen h_Lknow_sdb=m_Lknow_sdb+1.96*sd_Lknow_sdb

* Differences in SDB by awareness
gen know_sdb=Hknow_sdb-Lknow_sdb
egen sd_know_sdb=sd(know_sdb),  by(study_num)
gen m_know_sdb=m_Hknow_sdb-m_Lknow_sdb
gen l_know_sdb=m_know_sdb-1.96*sd_know_sdb
gen h_know_sdb=m_know_sdb+1.96*sd_know_sdb

*p value of difference
gen p_know_sdb=1-normal(m_know_sdb/sd_know_sdb)

*compare sdb for education and awareness
tabstat m_edu_sdb l_edu_sdb h_edu_sdb p_edu_sdb m_know_sdb l_know_sdb h_know_sdb p_know_sdb if study_num==22 


******************************************************************************
*Robustness of H1: Add stigma hypothetical, Honduras 2009
******************************************************************************

* VB estimates by stigma
gen stigma1_ind=invlogit(d_stigma+d_cons)
replace stigma1_ind=invlogit(d_cons) if study_num==34
gen stigma2_ind=invlogit(d_stigma*2+d_cons)
replace stigma2_ind=invlogit(d_stigma2+d_cons) if study_num==34
gen stigma3_ind=invlogit(d_stigma*3+d_cons)
replace stigma3_ind=invlogit(d_stigma3+d_cons) if study_num==34
gen stigma4_ind=invlogit(d_stigma*4+d_cons)
replace stigma4_ind=invlogit(d_stigma4+d_cons) if study_num==34

gen stigma1_list=t_stigma+t_cons
replace stigma1_list=t_cons if study_num==34
gen stigma2_list=t_stigma*2+t_cons
replace stigma2_list=t_stigma2+t_cons if study_num==34
gen stigma3_list=t_stigma*3+t_cons
replace stigma3_list=t_stigma3+t_cons if study_num==34
gen stigma4_list=t_stigma*4+t_cons
replace stigma4_list=t_stigma4+t_cons if study_num==34

*SDB estimates by stigma
gen stigma1_sdb=stigma1_list-stigma1_ind
gen stigma2_sdb=stigma2_list-stigma2_ind
gen stigma3_sdb=stigma3_list-stigma3_ind
gen stigma4_sdb=stigma4_list-stigma4_ind

*Table C5
tabstat stigma1_sdb stigma2_sdb stigma3_sdb stigma4_sdb if study_num>32 , by(study_num) statistics (mean sd p5 p95) columns(statistics)




******************************************************************************
** H2 SES perception sensitivity
******************************************************************************

* Income nonresponse VB estimates
gen incMiss_ind=invlogit(d_incNA*c_max_incNA+d_cons) if study_num<11
egen m_incMiss_ind=mean(incMiss_ind) if study_num<11, by(study_num2)
gen incMiss_list=t_incNA*c_max_incNA+t_cons if study_num<11
egen m_incMiss_list=mean(incMiss_list) if study_num<11, by(study_num2)

* Income response VB estimates
gen incResp_ind=invlogit(d_cons+d_incNA*c_min_incNA) if study_num<11
egen m_incResp_ind=mean(incResp_ind) if study_num<11, by(study_num2)
gen incResp_list=t_cons+t_incNA*c_min_incNA if study_num<11
egen m_incResp_list=mean(incResp_list) if study_num<11, by(study_num2) 


* Income nonresponse sdb estimates
gen incMiss_sdb=incMiss_list-incMiss_ind
egen sd_incMiss_sdb=sd(incMiss_sdb), by(study_num2)
gen m_incMiss_sdb=m_incMiss_list-m_incMiss_ind
replace m_incMiss_sdb=0 if m_incMiss_sdb<0
gen z_incMiss_sdb=m_incMiss_sdb/sd_incMiss
gen w_incMiss_sdb=1/sd_incMiss_sdb^2
gen l_incMiss_sdb=m_incMiss_sdb-1.96*sd_incMiss_sdb
gen h_incMiss_sdb=m_incMiss_sdb+1.96*sd_incMiss_sdb

* Income response SDB estimates
gen incResp_sdb=incResp_list-incResp_ind
egen sd_incResp_sdb=sd(incResp_sdb), by(study_num2)
gen m_incResp_sdb=m_incResp_list-m_incResp_ind
replace m_incResp_sdb=0 if m_incResp_sdb<0
gen z_incResp_sdb=m_incResp_sdb/sd_incResp
gen w_incResp_sdb=1/sd_incResp_sdb^2
gen l_incResp_sdb=m_incResp_sdb-1.96*sd_incResp_sdb
gen h_incResp_sdb=m_incResp_sdb+1.96*sd_incResp_sdb

* Difference in SDB by income response
gen incans_sdb=incMiss_sdb-incResp_sdb
egen sd_incans_sdb=sd(incans_sdb),  by(study_num2)
gen m_incans_sdb=m_incMiss_sdb-m_incResp_sdb
gen z_incans_sdb=m_incans_sdb/sd_incMiss
gen w_incans_sdb=1/sd_incans_sdb^2
gen l_incans_sdb=m_incans_sdb-1.96*sd_incans_sdb
gen h_incans_sdb=m_incans_sdb+1.96*sd_incans_sdb



*Meta analysis of effect size
metan m_incans_sdb sd_incans_sdb if id==1 & study_num2<7,  random nograph

replace m_incans_sdb=r(ES) if study_num2==7
replace sd_incans_sdb=r(seES) if study_num2==7
replace l_incans_sdb=r(ci_low) if study_num2==7
replace h_incans_sdb=r(ci_upp) if study_num2==7

gen p_incans_sdb=1-normal(m_incans_sdb/sd_incans_sdb)
format p_incans_sdb %9.2f
table study_num2, c(mean m_incans_sdb mean p_incans_sdb)

*Figure 3
splitvallabels xaxis2b , length(14)
twoway 	(scatter m_incResp_sdb xaxis2b, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_incResp_sdb xaxis2b h_incResp_sdb xaxis2b, lcolor(black) lwidth(vthin)) ///
		(scatter m_incMiss_sdb xaxis1b, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_incMiss_sdb xaxis1b l_incMiss_sdb xaxis1b, lcolor(black) lwidth(vthin)) /// 
		(scatter m_incans_sdb xaxis3b, mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_incans_sdb xaxis3b h_incans_sdb xaxis3b, lcolor(black) lwidth(vthin)) if id>9999 & study_num2!=., ///
		ytitle(Estimated Social Desirability Bias) ytitle(, size(medsmall)) ylabel(, labels ) ///
		xtitle("Study") xtitle(, size(medsmall) color(none))  xlabel(#7 `r(relabel)', labels labsize(small) ///
		format(%12s) valuelabel) legend(on order(3 "Income No Answer" 1 "Income Answered"  5 "Difference") ///
		rows(1) size(medsmall) position(12) ring(0)) xscale(range(1.5 14.5)) graphregion(color(white))

graph export Figure3.tif, replace

******************************************************************************
*Robustness replace incNA with incRef and IncDK for Mexico
******************************************************************************

* Income refusal VB estimates
gen incMiss_ind2=invlogit(d_incNA*c_max_incNA+d_cons) 
replace incMiss_ind2=. if study_num2==2
replace incMiss_ind2=invlogit(d_incNA*c_max_incREF+d_incDK*c_min_incDK+d_cons) if study_num==22
egen m_incMiss_ind2=mean(incMiss_ind2) , by(study_num)
gen incMiss_list2=t_incNA*c_max_incNA+t_cons 
replace incMiss_list2=. if study_num2==2
replace incMiss_list2=t_incNA*c_max_incREF+t_incDK*c_min_incDK+t_cons if study_num==22
egen m_incMiss_list2=mean(incMiss_list2) , by(study_num)

* Income response VB estimates
gen incResp_ind2=invlogit(d_cons+d_incNA*c_min_incNA) 
replace incResp_ind2=. if study_num2==2
replace incResp_ind2=invlogit(d_cons+d_incDK*c_min_incDK+d_incNA*c_min_incREF) if study_num==22
egen m_incResp_ind2=mean(incResp_ind2) , by(study_num)
gen incResp_list2=t_cons+t_incNA*c_min_incNA 
replace incResp_list2=. if study_num2==2
replace incResp_list2=t_cons+t_incDK*c_min_incDK+t_incNA*c_min_incREF if study_num==22
egen m_incResp_list2=mean(incResp_list2) , by(study_num) 

* Income refusal sdb estimates
gen incMiss_sdb2=incMiss_list2-incMiss_ind2
egen sd_incMiss_sdb2=sd(incMiss_sdb2), by(study_num)
gen m_incMiss_sdb2=m_incMiss_list2-m_incMiss_ind2
replace m_incMiss_sdb2=0 if m_incMiss_sdb2<0
gen z_incMiss_sdb2=m_incMiss_sdb2/sd_incMiss_sdb2
gen w_incMiss_sdb2=1/sd_incMiss_sdb2^2
gen l_incMiss_sdb2=m_incMiss_sdb2-1.96*sd_incMiss_sdb2
gen h_incMiss_sdb2=m_incMiss_sdb2+1.96*sd_incMiss_sdb2

* Income response sdb estimates
gen incResp_sdb2=incResp_list2-incResp_ind2
egen sd_incResp_sdb2=sd(incResp_sdb2), by(study_num)
gen m_incResp_sdb2=m_incResp_list2-m_incResp_ind2
replace m_incResp_sdb2=0 if m_incResp_sdb2<0
gen z_incResp_sdb2=m_incResp_sdb2/sd_incResp_sdb2
gen w_incResp_sdb2=1/sd_incResp_sdb2^2
gen l_incResp_sdb2=m_incResp_sdb2-1.96*sd_incResp_sdb2
gen h_incResp_sdb2=m_incResp_sdb2+1.96*sd_incResp_sdb2

*difference in SDB estimates
gen incans_sdb2=incMiss_sdb2-incResp_sdb2
egen sd_incans_sdb2=sd(incans_sdb2),  by(study_num)
gen m_incans_sdb2=m_incMiss_sdb2-m_incResp_sdb2
gen z_incans_sdb2=m_incans_sdb2/sd_incMiss_sdb2
gen w_incans_sdb2=1/sd_incans_sdb2^2
gen l_incans_sdb2=m_incans_sdb2-1.96*sd_incans_sdb2
gen h_incans_sdb2=m_incans_sdb2+1.96*sd_incans_sdb2

*Meta analysis of effect size
metan m_incans_sdb2 sd_incans_sdb2 if id==1  & study_num2!=2 & study_num<23,  random nograph

replace m_incans_sdb2=r(ES) if study_num2==7
replace sd_incans_sdb2=r(seES) if study_num2==7
replace l_incans_sdb2=r(ci_low) if study_num2==7
replace h_incans_sdb2=r(ci_upp) if study_num2==7

gen p_incans_sdb2=1-normal(m_incans_sdb2/sd_incans_sdb2)
format p_incans_sdb2 %9.2f
table study_num if   study_num2!=2 & study_num<23, c(mean m_incans_sdb2 mean p_incans_sdb2)
table study_num2 if   study_num2==7, c(mean m_incans_sdb2 mean p_incans_sdb2)



******************************************************************************
******************************************************************************
******************************************************************************

******************************************************************************
****Alternative hypotheses, reported in Appendix D
******************************************************************************

******************************************************************************
*** Income/wealth
******************************************************************************

gen rich_ind=invlogit(d_std_inc*2+d_incNA*c_min_incNA+d_cons) if study_num<11
egen m_rich_ind=mean(rich_ind) if study_num<11, by(study_num2)
gen rich_list=t_std_inc*2+t_incNA*c_min_incNA+t_cons if study_num<11
egen m_rich_list=mean(rich_list) if study_num<11, by(study_num2)

gen poor_ind=invlogit(d_std_inc*(-1)+d_incNA*c_min_incNA+d_cons) if study_num<11
egen m_poor_ind=mean(poor_ind) if study_num<11, by(study_num2)
gen poor_list=t_std_inc*(-1)+t_incNA*c_min_incNA+t_cons if study_num<11
egen m_poor_list=mean(poor_list) if study_num<11, by(study_num2) 


gen rich_sdb=rich_list-rich_ind
egen sd_rich_sdb=sd(rich_sdb), by(study_num2)
gen m_rich_sdb=m_rich_list-m_rich_ind
replace m_rich_sdb=0 if m_rich_sdb<0
gen z_rich_sdb=m_rich_sdb/sd_rich
gen w_rich_sdb=1/sd_rich_sdb^2
gen l_rich_sdb=m_rich_sdb-1.96*sd_rich_sdb
gen h_rich_sdb=m_rich_sdb+1.96*sd_rich_sdb


gen poor_sdb=poor_list-poor_ind
egen sd_poor_sdb=sd(poor_sdb), by(study_num2)
gen m_poor_sdb=m_poor_list-m_poor_ind
replace m_poor_sdb=0 if m_poor_sdb<0
gen z_poor_sdb=m_poor_sdb/sd_poor
gen w_poor_sdb=1/sd_poor_sdb^2
gen l_poor_sdb=m_poor_sdb-1.96*sd_poor_sdb
gen h_poor_sdb=m_poor_sdb+1.96*sd_poor_sdb


gen income_sdb=rich_sdb-poor_sdb
egen sd_income_sdb=sd(income_sdb),  by(study_num2)
gen m_income_sdb=m_rich_sdb-m_poor_sdb
gen z_income_sdb=m_income_sdb/sd_rich
gen w_income_sdb=1/sd_income_sdb^2
gen l_income_sdb=m_income_sdb-1.96*sd_income_sdb
gen h_income_sdb=m_income_sdb+1.96*sd_income_sdb



*Meta analysis of effect size
metan m_income_sdb sd_income_sdb if id==1 & study_num2<7,  random nograph

replace m_income_sdb=r(ES) if study_num2==7
replace sd_income_sdb=r(seES) if study_num2==7
replace l_income_sdb=r(ci_low) if study_num2==7
replace h_income_sdb=r(ci_upp) if study_num2==7

gen p_income_sdb=1-normal(m_income_sdb/sd_income_sdb)
format p_income_sdb %9.2f
table study_num2, c(mean p_income_sdb)


*Figure D1
splitvallabels xaxis2b , length(14)
twoway 	(scatter m_poor_sdb xaxis2b, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_poor_sdb xaxis2b h_poor_sdb xaxis2b, lcolor(black) lwidth(vthin)) ///
		(scatter m_rich_sdb xaxis1b, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_rich_sdb xaxis1b l_rich_sdb xaxis1b, lcolor(black) lwidth(vthin)) /// 
		(scatter m_income_sdb xaxis3b, mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_income_sdb xaxis3b h_income_sdb xaxis3b, lcolor(black) lwidth(vthin)) if id>9999 & study_num2!=., ///
		ytitle(Estimated Social Desirability Bias) ytitle(, size(medsmall)) ylabel(, labels ) ///
		xtitle("Study") xtitle(, size(medsmall) color(none)) xlabel(#7 `r(relabel)', labels labsize(small) ///
		format(%12s) valuelabel) legend(on order(3 "Wealthy (+2 sd)" 1 "Poor (-1 sd)"  5 "Difference") ///
		rows(1) size(medsmall) position(12) ring(0)) xscale(range(1.5 14.5)) graphregion(color(white))

graph export FigureF1.tif, replace


******************************************************************************
*** Clientelistic party identification
******************************************************************************

gen nonclient_ind=invlogit(d_clientexp*c_min_clientexp+d_cons) if study_num<11
replace nonclient_ind=invlogit(d_PIDstrength*c_min_PIDstrength+d_cons) if  study_num2==1
egen m_nonclient_ind=mean(nonclient_ind) if study_num<11, by(study_num2)
gen nonclient_list=t_clientexp*c_min_clientexp+t_cons if study_num<11
replace nonclient_list=t_PIDstrength*c_min_PIDstrength+t_cons if study_num2==1
egen m_nonclient_list=mean(nonclient_list) if study_num<11, by(study_num2)

gen client_ind=invlogit(d_clientexp*c_max_clientexp+d_cons) if study_num<11
replace client_ind=invlogit(d_PIDstrength*c_max_PIDstrength+d_cons) if study_num2==1
egen m_client_ind=mean(client_ind) if study_num<11, by(study_num2)
gen client_list=t_clientexp*c_max_clientexp+t_cons if study_num<11
replace client_list=t_PIDstrength*c_max_PIDstrength+t_cons  if study_num2==1
egen m_client_list=mean(client_list) if study_num<11, by(study_num2) 


gen nonclient_sdb=nonclient_list-nonclient_ind
egen sd_nonclient_sdb=sd(nonclient_sdb), by(study_num2)
gen m_nonclient_sdb=m_nonclient_list-m_nonclient_ind
replace m_nonclient_sdb=0 if m_nonclient_sdb<0
gen z_nonclient_sdb=m_nonclient_sdb/sd_nonclient
gen w_nonclient_sdb=1/sd_nonclient_sdb^2
gen l_nonclient_sdb=m_nonclient_sdb-1.96*sd_nonclient_sdb
gen h_nonclient_sdb=m_nonclient_sdb+1.96*sd_nonclient_sdb


gen client_sdb=client_list-client_ind
egen sd_client_sdb=sd(client_sdb), by(study_num2)
gen m_client_sdb=m_client_list-m_client_ind
replace m_client_sdb=0 if m_client_sdb<0
gen z_client_sdb=m_client_sdb/sd_client_sdb
gen w_client_sdb=1/sd_client_sdb^2
gen l_client_sdb=m_client_sdb-1.96*sd_client_sdb
gen h_client_sdb=m_client_sdb+1.96*sd_client_sdb


gen clientelism_sdb=nonclient_sdb-client_sdb
egen sd_clientelism_sdb=sd(clientelism_sdb),  by(study_num2)
gen m_clientelism_sdb=m_nonclient_sdb-m_client_sdb
gen z_clientelism_sdb=m_clientelism_sdb/sd_nonclient
gen w_clientelism_sdb=1/sd_clientelism_sdb^2
gen l_clientelism_sdb=m_clientelism_sdb-1.96*sd_clientelism_sdb
gen h_clientelism_sdb=m_clientelism_sdb+1.96*sd_clientelism_sdb



*Meta analysis of effect size
metan m_clientelism_sdb sd_clientelism_sdb if id==1 & study_num2<7,  random nograph

replace m_clientelism_sdb=r(ES) if study_num2==7
replace sd_clientelism_sdb=r(seES) if study_num2==7
replace l_clientelism_sdb=r(ci_low) if study_num2==7
replace h_clientelism_sdb=r(ci_upp) if study_num2==7

gen p_clientelism_sdb=1-normal(m_clientelism_sdb/sd_clientelism_sdb)
format p_clientelism_sdb %9.2f
table study_num2, c(mean p_clientelism_sdb)

*Figure D2
splitvallabels xaxis2b , length(14)
twoway 	(scatter m_client_sdb xaxis2b, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_client_sdb xaxis2b h_client_sdb xaxis2b, lcolor(black) lwidth(vthin)) ///
		(scatter m_nonclient_sdb xaxis1b, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_nonclient_sdb xaxis1b l_nonclient_sdb xaxis1b, lcolor(black) lwidth(vthin)) /// 
		(scatter m_clientelism_sdb xaxis3b, mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_clientelism_sdb xaxis3b h_clientelism_sdb xaxis3b, lcolor(black) lwidth(vthin)) if id>9999 & study_num2!=., ///
		ytitle(Estimated Social Desirability Bias) ytitle(, size(medsmall)) ylabel(, labels ) ///
		xtitle("Study") xtitle(, size(medsmall) color(none)) xlabel(#7 `r(relabel)', labels labsize(small) ///
		format(%12s) valuelabel) legend(on order(3 "Non-Clientelistic Party" 1 "Clientelistic Party"  5 "Difference") ///
		rows(1) size(medsmall) position(12) ring(0)) xscale(range(1.5 14.5)) graphregion(color(white))
		
graph export FigureF2.tif, replace


******************************************************************************
*Partisan Strength
******************************************************************************

gen PIDstrong_ind=invlogit(d_PIDstrength*c_max_PIDstrength+d_cons) if study_num<11
egen m_PIDstrong_ind=mean(PIDstrong_ind) if study_num<11, by(study_num2)
gen PIDstrong_list=t_PIDstrength*c_max_PIDstrength+t_cons if study_num<11
egen m_PIDstrong_list=mean(PIDstrong_list) if study_num<11, by(study_num2)

gen indep_ind=invlogit(d_PIDstrength*c_min_PIDstrength+d_cons) if study_num<11
egen m_indep_ind=mean(indep_ind) if study_num<11, by(study_num2)
gen indep_list=t_PIDstrength*c_min_PIDstrength+t_cons if study_num<11
egen m_indep_list=mean(indep_list) if study_num<11, by(study_num2) 


gen PIDstrong_sdb=PIDstrong_list-PIDstrong_ind
egen sd_PIDstrong_sdb=sd(PIDstrong_sdb), by(study_num2)
gen m_PIDstrong_sdb=m_PIDstrong_list-m_PIDstrong_ind
replace m_PIDstrong_sdb=0 if m_PIDstrong_sdb<0
gen z_PIDstrong_sdb=m_PIDstrong_sdb/sd_PIDstrong
gen w_PIDstrong_sdb=1/sd_PIDstrong_sdb^2
gen l_PIDstrong_sdb=m_PIDstrong_sdb-1.96*sd_PIDstrong_sdb
gen h_PIDstrong_sdb=m_PIDstrong_sdb+1.96*sd_PIDstrong_sdb


gen indep_sdb=indep_list-indep_ind
egen sd_indep_sdb=sd(indep_sdb), by(study_num2)
gen m_indep_sdb=m_indep_list-m_indep_ind
replace m_indep_sdb=0 if m_indep_sdb<0
gen z_indep_sdb=m_indep_sdb/sd_indep_sdb
gen w_indep_sdb=1/sd_indep_sdb^2
gen l_indep_sdb=m_indep_sdb-1.96*sd_indep_sdb
gen h_indep_sdb=m_indep_sdb+1.96*sd_indep_sdb


gen PID_sdb=PIDstrong_sdb-indep_sdb
egen sd_PID_sdb=sd(PID_sdb),  by(study_num2)
gen m_PID_sdb=m_PIDstrong_sdb-m_indep_sdb
gen z_PID_sdb=m_PID_sdb/sd_PIDstrong
gen w_PID_sdb=1/sd_PID_sdb^2
gen l_PID_sdb=m_PID_sdb-1.96*sd_PID_sdb
gen h_PID_sdb=m_PID_sdb+1.96*sd_PID_sdb



*Meta analysis of effect size
metan m_PID_sdb sd_PID_sdb if id==1 & study_num2<7,  random nograph

replace m_PID_sdb=r(ES) if study_num2==7
replace sd_PID_sdb=r(seES) if study_num2==7
replace l_PID_sdb=r(ci_low) if study_num2==7
replace h_PID_sdb=r(ci_upp) if study_num2==7

gen p_PID_sdb=1-normal(m_PID_sdb/sd_PID_sdb)
format p_PID_sdb %9.2f
table study_num2, c(mean p_PID_sdb)


*Figure D3
splitvallabels xaxis2b , length(14)
twoway 	(scatter m_indep_sdb xaxis2b, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_indep_sdb xaxis2b h_indep_sdb xaxis2b, lcolor(black) lwidth(vthin)) ///
		(scatter m_PIDstrong_sdb xaxis1b, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_PIDstrong_sdb xaxis1b l_PIDstrong_sdb xaxis1b, lcolor(black) lwidth(vthin)) /// 
		(scatter m_PID_sdb xaxis3b, mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_PID_sdb xaxis3b h_PID_sdb xaxis3b, lcolor(black) lwidth(vthin)) if id>9999 & study_num2!=., ///
		ytitle(Estimated Social Desirability Bias) ytitle(, size(medsmall)) ylabel(, labels ) ///
		xtitle("Study") xtitle(, size(medsmall) color(none)) xlabel(#7 `r(relabel)', labels labsize(small) ///
		format(%12s) valuelabel) legend(on order(3 "Strong Partisan" 1 "Independent"  5 "Difference") ///
		rows(1) size(medsmall) position(12) ring(0)) xscale(range(1.5 14.5)) yscale(range(-.5 .75)) graphregion(color(white))
		
graph export FigureF3.tif, replace

******************************************************************************
*Voted
******************************************************************************

gen Voted_ind=invlogit(d_Voted*c_max_Voted+d_cons) if study_num<11
egen m_Voted_ind=mean(Voted_ind) if study_num<11, by(study_num2)
gen Voted_list=t_Voted*c_max_Voted+t_cons if study_num<11
egen m_Voted_list=mean(Voted_list) if study_num<11, by(study_num2)

gen Abstained_ind=invlogit(d_Voted*c_min_Voted+d_cons) if study_num<11
egen m_Abstained_ind=mean(Abstained_ind) if study_num<11, by(study_num2)
gen Abstained_list=t_Voted*c_min_Voted+t_cons if study_num<11
egen m_Abstained_list=mean(Abstained_list) if study_num<11, by(study_num2) 


gen Voted_sdb=Voted_list-Voted_ind
egen sd_Voted_sdb=sd(Voted_sdb), by(study_num2)
gen m_Voted_sdb=m_Voted_list-m_Voted_ind
replace m_Voted_sdb=0 if m_Voted_sdb<0
gen z_Voted_sdb=m_Voted_sdb/sd_Voted
gen w_Voted_sdb=1/sd_Voted_sdb^2
gen l_Voted_sdb=m_Voted_sdb-1.96*sd_Voted_sdb
gen h_Voted_sdb=m_Voted_sdb+1.96*sd_Voted_sdb


gen Abstained_sdb=Abstained_list-Abstained_ind
egen sd_Abstained_sdb=sd(Abstained_sdb), by(study_num2)
gen m_Abstained_sdb=m_Abstained_list-m_Abstained_ind
replace m_Abstained_sdb=0 if m_Abstained_sdb<0
gen z_Abstained_sdb=m_Abstained_sdb/sd_Abstained_sdb
gen w_Abstained_sdb=1/sd_Abstained_sdb^2
gen l_Abstained_sdb=m_Abstained_sdb-1.96*sd_Abstained_sdb
gen h_Abstained_sdb=m_Abstained_sdb+1.96*sd_Abstained_sdb


gen turnout_sdb=Voted_sdb-Abstained_sdb
egen sd_turnout_sdb=sd(turnout_sdb),  by(study_num2)
gen m_turnout_sdb=m_Voted_sdb-m_Abstained_sdb
gen z_turnout_sdb=m_turnout_sdb/sd_Voted
gen w_turnout_sdb=1/sd_turnout_sdb^2
gen l_turnout_sdb=m_turnout_sdb-1.96*sd_turnout_sdb
gen h_turnout_sdb=m_turnout_sdb+1.96*sd_turnout_sdb



*Meta analysis of effect size
metan m_turnout_sdb sd_turnout_sdb if id==1 & study_num2<7,  random nograph

replace m_turnout_sdb=r(ES) if study_num2==7
replace sd_turnout_sdb=r(seES) if study_num2==7
replace l_turnout_sdb=r(ci_low) if study_num2==7
replace h_turnout_sdb=r(ci_upp) if study_num2==7

gen p_turnout_sdb=1-normal(m_turnout_sdb/sd_turnout_sdb)
format p_turnout_sdb %9.2f
table study_num2, c(mean p_turnout_sdb)

*Figure D4
splitvallabels xaxis2b , length(14)
twoway 	(scatter m_Abstained_sdb xaxis2b, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_Abstained_sdb xaxis2b h_Abstained_sdb xaxis2b, lcolor(black) lwidth(vthin)) ///
		(scatter m_Voted_sdb xaxis1b, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_Voted_sdb xaxis1b l_Voted_sdb xaxis1b, lcolor(black) lwidth(vthin)) /// 
		(scatter m_turnout_sdb xaxis3b, mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_turnout_sdb xaxis3b h_turnout_sdb xaxis3b, lcolor(black) lwidth(vthin)) if id>9999 & study_num2!=., ///
		ytitle(Estimated Social Desirability Bias) ytitle(, size(medsmall)) ylabel(, labels ) ///
		xtitle( "Study") xtitle(, size(medsmall) color(none)) xlabel(#7 `r(relabel)', labels labsize(small) ///
		format(%12s) valuelabel) legend(on order(3 "Voted" 1 "Abstained"  5 "Difference") ///
		rows(1) size(medsmall) position(12) ring(0)) xscale(range(1.5 14.5)) yscale(range(-.4 .6)) graphregion(color(white))
		
graph export FigureF4.tif, replace


******************************************************************************
*Ballot Secrecy / Monitoring
******************************************************************************

gen notsecret_ind=invlogit(d_monitor*c_max_monitor+d_cons) if study_num<11
egen m_notsecret_ind=mean(notsecret_ind) if study_num<11, by(study_num2)
gen notsecret_list=t_monitor*c_max_monitor+t_cons if study_num<11
egen m_notsecret_list=mean(notsecret_list) if study_num<11, by(study_num2)

gen secret_ind=invlogit(d_monitor*c_min_monitor+d_cons) if study_num<11
egen m_secret_ind=mean(secret_ind) if study_num<11, by(study_num2)
gen secret_list=t_monitor*c_min_monitor+t_cons if study_num<11
egen m_secret_list=mean(secret_list) if study_num<11, by(study_num2) 


gen notsecret_sdb=notsecret_list-notsecret_ind
egen sd_notsecret_sdb=sd(notsecret_sdb), by(study_num2)
gen m_notsecret_sdb=m_notsecret_list-m_notsecret_ind
replace m_notsecret_sdb=0 if m_notsecret_sdb<0
gen z_notsecret_sdb=m_notsecret_sdb/sd_notsecret
gen w_notsecret_sdb=1/sd_notsecret_sdb^2
gen l_notsecret_sdb=m_notsecret_sdb-1.96*sd_notsecret_sdb
gen h_notsecret_sdb=m_notsecret_sdb+1.96*sd_notsecret_sdb


gen secret_sdb=secret_list-secret_ind
egen sd_secret_sdb=sd(secret_sdb), by(study_num2)
gen m_secret_sdb=m_secret_list-m_secret_ind
replace m_secret_sdb=0 if m_secret_sdb<0
gen z_secret_sdb=m_secret_sdb/sd_secret_sdb
gen w_secret_sdb=1/sd_secret_sdb^2
gen l_secret_sdb=m_secret_sdb-1.96*sd_secret_sdb
gen h_secret_sdb=m_secret_sdb+1.96*sd_secret_sdb


gen monitor_sdb=notsecret_sdb-secret_sdb
egen sd_monitor_sdb=sd(monitor_sdb),  by(study_num2)
gen m_monitor_sdb=m_notsecret_sdb-m_secret_sdb
gen z_monitor_sdb=m_monitor_sdb/sd_notsecret
gen w_monitor_sdb=1/sd_monitor_sdb^2
gen l_monitor_sdb=m_monitor_sdb-1.96*sd_monitor_sdb
gen h_monitor_sdb=m_monitor_sdb+1.96*sd_monitor_sdb



*Meta analysis of effect size
metan m_monitor_sdb sd_monitor_sdb if id==1 & study_num2<7,  random nograph

replace m_monitor_sdb=r(ES) if study_num2==7
replace sd_monitor_sdb=r(seES) if study_num2==7
replace l_monitor_sdb=r(ci_low) if study_num2==7
replace h_monitor_sdb=r(ci_upp) if study_num2==7

gen p_monitor_sdb=2*(1-normal(m_monitor_sdb/sd_monitor_sdb))
format p_monitor_sdb %9.2f
table study_num2, c(mean p_monitor_sdb)

*Figure D5
splitvallabels xaxis2b , length(14)
twoway 	(scatter m_secret_sdb xaxis2b, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_secret_sdb xaxis2b h_secret_sdb xaxis2b, lcolor(black) lwidth(vthin)) ///
		(scatter m_notsecret_sdb xaxis1b, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_notsecret_sdb xaxis1b l_notsecret_sdb xaxis1b, lcolor(black) lwidth(vthin)) /// 
		(scatter m_monitor_sdb xaxis3b, mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_monitor_sdb xaxis3b h_monitor_sdb xaxis3b, lcolor(black) lwidth(vthin)) if id>9999 & study_num2!=., ///
		ytitle(Estimated Social Desirability Bias) ytitle(, size(medsmall)) ylabel(, labels ) ///
		xtitle("Study") xtitle(, size(medsmall) color(none)) xlabel(#7 `r(relabel)', labels labsize(small) ///
		format(%12s) valuelabel) legend(on order(3 "Vote Note Secret" 1 "Secret"  5 "Difference") ///
		rows(1) size(medsmall) position(12) ring(0)) xscale(range(1.5 14.5)) yscale(range(-.6 .8)) graphregion(color(white))
		
graph export FigureF5.tif, replace

******************************************************************************
*Reciprocity
******************************************************************************

gen Hrecip_ind=invlogit(d_recip*c_max_monitor+d_cons) if study_num<11
egen m_Hrecip_ind=mean(Hrecip_ind) if study_num<11, by(study_num2)
gen Hrecip_list=t_recip*c_max_monitor+t_cons if study_num<11
egen m_Hrecip_list=mean(Hrecip_list) if study_num<11, by(study_num2)

gen Lrecip_ind=invlogit(d_recip*c_min_monitor+d_cons) if study_num<11
egen m_Lrecip_ind=mean(Lrecip_ind) if study_num<11, by(study_num2)
gen Lrecip_list=t_recip*c_min_monitor+t_cons if study_num<11
egen m_Lrecip_list=mean(Lrecip_list) if study_num<11, by(study_num2) 


gen Hrecip_sdb=Hrecip_list-Hrecip_ind
egen sd_Hrecip_sdb=sd(Hrecip_sdb), by(study_num2)
gen m_Hrecip_sdb=m_Hrecip_list-m_Hrecip_ind
replace m_Hrecip_sdb=0 if m_Hrecip_sdb<0
gen z_Hrecip_sdb=m_Hrecip_sdb/sd_Hrecip
gen w_Hrecip_sdb=1/sd_Hrecip_sdb^2
gen l_Hrecip_sdb=m_Hrecip_sdb-1.96*sd_Hrecip_sdb
gen h_Hrecip_sdb=m_Hrecip_sdb+1.96*sd_Hrecip_sdb


gen Lrecip_sdb=Lrecip_list-Lrecip_ind
egen sd_Lrecip_sdb=sd(Lrecip_sdb), by(study_num2)
gen m_Lrecip_sdb=m_Lrecip_list-m_Lrecip_ind
replace m_Lrecip_sdb=0 if m_Lrecip_sdb<0
gen z_Lrecip_sdb=m_Lrecip_sdb/sd_Lrecip_sdb
gen w_Lrecip_sdb=1/sd_Lrecip_sdb^2
gen l_Lrecip_sdb=m_Lrecip_sdb-1.96*sd_Lrecip_sdb
gen h_Lrecip_sdb=m_Lrecip_sdb+1.96*sd_Lrecip_sdb


gen recip_sdb=Hrecip_sdb-Lrecip_sdb
egen sd_recip_sdb=sd(recip_sdb),  by(study_num2)
gen m_recip_sdb=m_Hrecip_sdb-m_Lrecip_sdb
gen z_recip_sdb=m_recip_sdb/sd_Hrecip
gen w_recip_sdb=1/sd_recip_sdb^2
gen l_recip_sdb=m_recip_sdb-1.96*sd_recip_sdb
gen h_recip_sdb=m_recip_sdb+1.96*sd_recip_sdb



*Meta analysis of effect size
metan m_recip_sdb sd_recip_sdb if id==1 & study_num2<7,  random nograph

replace m_recip_sdb=r(ES) if study_num2==7
replace sd_recip_sdb=r(seES) if study_num2==7
replace l_recip_sdb=r(ci_low) if study_num2==7
replace h_recip_sdb=r(ci_upp) if study_num2==7

gen p_recip_sdb=2*(1-normal(m_recip_sdb/sd_recip_sdb))
format p_recip_sdb %9.2f
table study_num2, c(mean p_recip_sdb)


*Figure D6
splitvallabels xaxis2b , length(14)
twoway 	(scatter m_Lrecip_sdb xaxis2b, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_Lrecip_sdb xaxis2b h_Lrecip_sdb xaxis2b, lcolor(black) lwidth(vthin)) ///
		(scatter m_Hrecip_sdb xaxis1b, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_Hrecip_sdb xaxis1b l_Hrecip_sdb xaxis1b, lcolor(black) lwidth(vthin)) /// 
		(scatter m_recip_sdb xaxis3b, mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_recip_sdb xaxis3b h_recip_sdb xaxis3b, lcolor(black) lwidth(vthin)) if id>9999 & study_num2!=., ///
		ytitle(Estimated Social Desirability Bias) ytitle(, size(medsmall)) ylabel(, labels ) ///
		xtitle("Study") xtitle(, size(medsmall) color(none)) xlabel(#7 `r(relabel)', labels labsize(small) ///
		format(%12s) valuelabel) legend(on order(3 "High Reciprocity" 1 "Low Reciprocity"  5 "Difference") ///
		rows(1) size(medsmall) position(12) ring(0)) xscale(range(1.5 14.5)) yscale(range(-.2 .5)) graphregion(color(white))
		
graph export FigureF6.tif, replace


******************************************************************************
*Gender
******************************************************************************

gen female_ind=invlogit(d_female*c_max_female+d_cons) if study_num<11
egen m_female_ind=mean(female_ind) if study_num<11, by(study_num2)
gen female_list=t_female*c_max_female+t_cons if study_num<11
egen m_female_list=mean(female_list) if study_num<11, by(study_num2)

gen male_ind=invlogit(d_female*c_min_female+d_cons) if study_num<11
egen m_male_ind=mean(male_ind) if study_num<11, by(study_num2)
gen male_list=t_female*c_min_female+t_cons if study_num<11
egen m_male_list=mean(male_list) if study_num<11, by(study_num2) 


gen female_sdb=female_list-female_ind
egen sd_female_sdb=sd(female_sdb), by(study_num2)
gen m_female_sdb=m_female_list-m_female_ind
replace m_female_sdb=0 if m_female_sdb<0
gen z_female_sdb=m_female_sdb/sd_female
gen w_female_sdb=1/sd_female_sdb^2
gen l_female_sdb=m_female_sdb-1.96*sd_female_sdb
gen h_female_sdb=m_female_sdb+1.96*sd_female_sdb


gen male_sdb=male_list-male_ind
egen sd_male_sdb=sd(male_sdb), by(study_num2)
gen m_male_sdb=m_male_list-m_male_ind
replace m_male_sdb=0 if m_male_sdb<0
gen z_male_sdb=m_male_sdb/sd_male_sdb
gen w_male_sdb=1/sd_male_sdb^2
gen l_male_sdb=m_male_sdb-1.96*sd_male_sdb
gen h_male_sdb=m_male_sdb+1.96*sd_male_sdb


gen gender_sdb=female_sdb-male_sdb
egen sd_gender_sdb=sd(gender_sdb),  by(study_num2)
gen m_gender_sdb=m_female_sdb-m_male_sdb
gen z_gender_sdb=m_gender_sdb/sd_female
gen w_gender_sdb=1/sd_gender_sdb^2
gen l_gender_sdb=m_gender_sdb-1.96*sd_gender_sdb
gen h_gender_sdb=m_gender_sdb+1.96*sd_gender_sdb



*Meta analysis of effect size
metan m_gender_sdb sd_gender_sdb if id==1 & study_num2<7,  random nograph

replace m_gender_sdb=r(ES) if study_num2==7
replace sd_gender_sdb=r(seES) if study_num2==7
replace l_gender_sdb=r(ci_low) if study_num2==7
replace h_gender_sdb=r(ci_upp) if study_num2==7

gen p_gender_sdb=2*(1-normal(m_gender_sdb/sd_gender_sdb))
format p_gender_sdb %9.2f
table study_num2, c(mean p_gender_sdb)

*Figure D7
splitvallabels xaxis2b , length(14)
twoway 	(scatter m_male_sdb xaxis2b, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_male_sdb xaxis2b h_male_sdb xaxis2b, lcolor(black) lwidth(vthin)) ///
		(scatter m_female_sdb xaxis1b, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_female_sdb xaxis1b l_female_sdb xaxis1b, lcolor(black) lwidth(vthin)) /// 
		(scatter m_gender_sdb xaxis3b, mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_gender_sdb xaxis3b h_gender_sdb xaxis3b, lcolor(black) lwidth(vthin)) if id>9999 & study_num2!=., ///
		ytitle(Estimated Social Desirability Bias) ytitle(, size(medsmall)) ylabel(, labels ) ///
		xtitle( "Study") xtitle(, size(medsmall) color(none)) xlabel(#7 `r(relabel)', labels labsize(small) ///
		format(%12s) valuelabel) legend(on order(3 "Females" 1 "Males"  5 "Difference") ///
		rows(1) size(medsmall) position(12) ring(0)) xscale(range(1.5 14.5)) yscale(range(-.4 .55)) graphregion(color(white))
		
graph export FigureF7.tif, replace


******************************************************************************
*Age
******************************************************************************


gen young_ind=invlogit(d_age*-1+d_cons) if study_num<11
egen m_young_ind=mean(young_ind) if study_num<11, by(study_num2)
gen young_list=t_age*-1+t_cons if study_num<11
egen m_young_list=mean(young_list) if study_num<11, by(study_num2)

gen old_ind=invlogit(d_age*2+d_cons) if study_num<11
egen m_old_ind=mean(old_ind) if study_num<11, by(study_num2)
gen old_list=t_age*2+t_cons if study_num<11
egen m_old_list=mean(old_list) if study_num<11, by(study_num2) 


gen young_sdb=young_list-young_ind
egen sd_young_sdb=sd(young_sdb), by(study_num2)
gen m_young_sdb=m_young_list-m_young_ind
replace m_young_sdb=0 if m_young_sdb<0
gen z_young_sdb=m_young_sdb/sd_young
gen w_young_sdb=1/sd_young_sdb^2
gen l_young_sdb=m_young_sdb-1.96*sd_young_sdb
gen h_young_sdb=m_young_sdb+1.96*sd_young_sdb


gen old_sdb=old_list-old_ind
egen sd_old_sdb=sd(old_sdb), by(study_num2)
gen m_old_sdb=m_old_list-m_old_ind
replace m_old_sdb=0 if m_old_sdb<0
gen z_old_sdb=m_old_sdb/sd_old_sdb
gen w_old_sdb=1/sd_old_sdb^2
gen l_old_sdb=m_old_sdb-1.96*sd_old_sdb
gen h_old_sdb=m_old_sdb+1.96*sd_old_sdb


gen age_sdb=old_sdb-young_sdb
egen sd_age_sdb=sd(age_sdb),  by(study_num2)
gen m_age_sdb=m_old_sdb-m_young_sdb
gen z_age_sdb=m_age_sdb/sd_young
gen w_age_sdb=1/sd_age_sdb^2
gen l_age_sdb=m_age_sdb-1.96*sd_age_sdb
gen h_age_sdb=m_age_sdb+1.96*sd_age_sdb



*Meta analysis of effect size
metan m_age_sdb sd_age_sdb if id==1 & study_num2<7,  random nograph

replace m_age_sdb=r(ES) if study_num2==7
replace sd_age_sdb=r(seES) if study_num2==7
replace l_age_sdb=r(ci_low) if study_num2==7
replace h_age_sdb=r(ci_upp) if study_num2==7

gen p_age_sdb=2*(1-normal(m_age_sdb/sd_age_sdb))
format p_age_sdb %9.2f
table study_num2, c(mean p_age_sdb)

*Figure D8
splitvallabels xaxis2b , length(14)
twoway 	(scatter m_young_sdb xaxis2b, mcolor(black) msize(small) msymbol(circle)) ///
		(pcspike h_young_sdb xaxis2b l_young_sdb xaxis2b, lcolor(black) lwidth(vthin)) /// 
		(scatter m_old_sdb xaxis1b, mcolor(black) msize(small) msymbol(triangle)) ///
		(pcspike l_old_sdb xaxis1b h_old_sdb xaxis1b, lcolor(black) lwidth(vthin)) ///
		(scatter m_age_sdb xaxis3b, mcolor(black) msize(small) msymbol(dh)) ///
		(pcspike l_age_sdb xaxis3b h_age_sdb xaxis3b, lcolor(black) lwidth(vthin)) if id>9999 & study_num2!=., ///
		ytitle(Estimated Social Desirability Bias) ytitle(, size(medsmall)) ylabel(, labels ) ///
		xtitle("Study") xtitle(, size(medsmall) color(none)) xlabel(#7 `r(relabel)', labels labsize(small) ///
		format(%12s) valuelabel) legend(on order(3 "Old" 1 "Young"  5 "Difference") ///
		rows(1) size(medsmall) position(12) ring(0)) xscale(range(1.5 14.5)) yscale(range(-.6 1.25)) graphregion(color(white))
		
graph export FigureF8.tif, replace
